List:Commits« Previous MessageNext Message »
From:klewis Date:February 28 2008 3:28pm
Subject:bk commit into 6.0 tree (klewis:1.2578) BUG#34632
View as plain text  
Below is the list of changes that have just been committed into a local
6.0 repository of klewis.  When klewis does a push these changes
will be propagated to the main repository and, within 24 hours after the
push, to the public repository.
For information on how to access the public repository
see http://dev.mysql.com/doc/mysql/en/installing-source-tree.html

ChangeSet@stripped, 2008-02-28 09:27:49-06:00, klewis@klewis-mysql. +1 -0
  Bug#34632 - a lock record can now have state == recUnlocked. In this case, 
  Table::checkUniqueRecordVersion should check the prior record.

  storage/falcon/Table.cpp@stripped, 2008-02-28 09:27:36-06:00, klewis@klewis-mysql. +2 -2
    Bug#34632 - a lock record can now have state == recUnlocked. In this case, 
    Table::checkUniqueRecordVersion should check the prior record.

diff -Nrup a/storage/falcon/Table.cpp b/storage/falcon/Table.cpp
--- a/storage/falcon/Table.cpp	2008-02-20 15:16:03 -06:00
+++ b/storage/falcon/Table.cpp	2008-02-28 09:27:36 -06:00
@@ -2434,9 +2434,9 @@ int Table::checkUniqueRecordVersion(int3
 
 		if (!dup->hasRecord())
 			{
 			// If the record is locked, keep looking for a dup.
 
-			if (dup->state == recLock)
+			if ((dup->state == recLock) || (dup->state == recUnlocked))
 				continue;  // Next record version.
 
 			// The record has been deleted.
@@ -2434,9 +2434,9 @@ int Table::checkUniqueRecordVersion(int3
 		if (!dup->hasRecord())
 			{
-			// If the record is locked, keep looking for a dup.
+			// If the record is locked or being unlocked keep looking for a dup.
 
Thread
bk commit into 6.0 tree (klewis:1.2578) BUG#34632klewis28 Feb